<?php

if( !class_exists('PH_Order_Delivery_Date_Admin_Helper') ){

	class PH_Order_Delivery_Date_Admin_Helper {

		public function __construct() {

			$this->settings_obj 	  = new PH_Order_Delivery_Date_Settings_Option();

            // To estimated delivery date field to checkout page
			add_filter( 'woocommerce_checkout_fields' , array( $this, 'ph_add_order_delivery_datepicker_fields_to_checkout') );

			add_filter( 'wp_enqueue_scripts', array( $this, 'ph_enqueue_front_end_scripts_show_date_picker') );

			// To display estimated date in Thank You Page
			add_filter( 'woocommerce_get_order_item_totals', array( $this, 'ph_display_order_delivery_date_in_thankyou_page'), 10, 2 );

			// Add Minimum and Maximum delivery days limit in Order Meta Data
			add_action( 'woocommerce_checkout_update_order_meta', array( $this, 'ph_order_delivery_date_update_order_meta' ), 10, 2 );

			// To display Order Delivery Date in Edit Order Page
			add_action( 'woocommerce_admin_order_data_after_billing_address', array( $this, 'ph_custom_checkout_field_display_in_edit_order_page' ), 10 );

			if ( is_admin() ) {

				add_action( 'add_meta_boxes', array( $this, 'ph_add_order_delivery_date_metabox' ), 15 );

				if ( isset( $_POST['update_order_delivery_date'] ) ) {

					add_action( 'init', array( $this, 'ph_update_order_delivery_date_meta_data' ), 10 );
				}
			}

		}

		public function ph_add_order_delivery_datepicker_fields_to_checkout( $fields) {

			if( isset($this->settings_obj->settings_enable) && $this->settings_obj->settings_enable == 'yes' ) {

				$fields['billing']['ph_order_delivery_date_field'] = array(
					'label' 			=> __( $this->settings_obj->display_text, 'ph_order_delivery_date_addon' ),
					'type' 				=> 'text',
					'required' 			=> false,
					'id' 				=> 'ph_datepicker',
					'default' 			=> '',
					'custom_attributes' => array('autocomplete' => 'off'),
				);
			}

			return $fields;
		}

		public function ph_enqueue_front_end_scripts_show_date_picker() {

			if ( is_checkout() ) {

				wp_enqueue_script( 'jquery-ui-datepicker' );
				
				wp_register_style( 'ph_jquery-ui', 'https://ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/themes/base/jquery-ui.css');
				wp_enqueue_style( 'ph_jquery-ui' );

				wp_enqueue_script( 'ph-order-date-scripts', plugins_url( '../resources/js/ph-min-max-datepicker.js', __FILE__ ), array( 'jquery' ) );
			}
		}

		public function ph_display_order_delivery_date_in_thankyou_page( $ids, $order ) {

			if ( isset($this->settings_obj->settings_enable) && $this->settings_obj->settings_enable == 'yes' ) {

				$delivery_date 	= get_post_meta( $order->get_id(), '_ph_order_delivery_date_value', true );

				if ( isset($delivery_date) && !empty($delivery_date) ) {

					$ids['_ph_order_delivery_date_value'] = array(
						'label'		=>	esc_attr( __( $this->settings_obj->display_text, 'ph_order_delivery_date_addon' ) ),
						'value'		=>	$delivery_date,
					);
				}

				return $ids;
			}
		}

		public function ph_order_delivery_date_update_order_meta( $order_id, $post ) {

			if ( isset($post['ph_order_delivery_date_field']) && !empty($post['ph_order_delivery_date_field']) ) {
				
				if(  WC() != null && WC()->session != null ) {

					$minDate    = !empty( WC()->session->get('ph_order_delivery_min_date') ) ? WC()->session->get('ph_order_delivery_min_date') : 0;

					// Add 365 Days when Max Days is not set
					if ( $this->settings_obj->max_day_limit == 0 ) {

						$this->settings_obj->max_day_limit = 365;
					}

					$order_date_meta   = array(
						'min_days'	=>	$this->settings_obj->min_delivery_days + $minDate,										
						'max_days'	=>	$this->settings_obj->max_day_limit + $minDate,
					);

					add_post_meta( $order_id, 'ph_order_delivery_date_min_and_max_days', $order_date_meta );
				}

				$order_delivery_date = $post['ph_order_delivery_date_field'];
				
				update_post_meta( $order_id, '_ph_order_delivery_date_value', $order_delivery_date );
			}

		}
		public function ph_custom_checkout_field_display_in_edit_order_page( $order ) { 

			if( isset($this->settings_obj->settings_enable) && $this->settings_obj->settings_enable == 'yes' ) {

				echo '<p><strong>'.$this->settings_obj->display_text.':</strong> ' . get_post_meta($order->get_id(), '_ph_order_delivery_date_value', true ) . '</p>';
			}
		}

		public function ph_add_order_delivery_date_metabox() {

			global $post;

			if ( !$post ) return;

			if ( !in_array( $post->post_type, array('shop_order') ) ) return;

			add_meta_box( "PH_Order_Delivery_Date_Metabox", __( 'Order Delivery Date', 'ph_order_delivery_date_addon' ), array( $this, 'ph_order_delivery_date_metabox_content' ), 'shop_order', 'side', 'default' );
		}

		public function ph_order_delivery_date_metabox_content() {

			global $post;

			$order_delivery_date 	= get_post_meta( $post->ID, '_ph_order_delivery_date_value', true );

			$est_delivery_date  	= get_post_meta( $post->ID, '_est_date', true );
			$min_delivery_days 		= $this->settings_obj->min_delivery_days;
			$max_day_limit 			= $this->settings_obj->max_day_limit;

			if ($this->settings_obj->ph_estimated_delivery_is_active) {

				$plugin_date        = get_post_meta( $post->ID ,'ph_order_delivery_date_min_and_max_days', true );

				if ( isset($plugin_date) && !empty($plugin_date) ) {

					$min_delivery_days  = $plugin_date['min_days'];
					$max_day_limit      = $plugin_date['max_days'];
				}
			}

			// Disable days in datepicker based on Working Days
			// If empty pass 7 as all are working days ( 0 = Sun & 6 = Sat )
			$non_working_days = !empty( $this->settings_obj->non_working_days ) ? $this->settings_obj->non_working_days : array( 0 => 7 );

			$display_format 	= $this->settings_obj->odd_display_format;

			// if( $this->settings_obj->odd_display_format == 'custom' ) {

			// 	$display_format 	= $this->settings_obj->odd_custom_format;
			// }

			?>
			<ul class="order_actions submitbox">

				<?php

				if ( $this->settings_obj->ph_estimated_delivery_is_active && !empty( $est_delivery_date ) ) {

					?>

					<li id="" class="wide">

						<strong><?php _e($this->settings_obj->cart_page_text, 'ph_order_delivery_date_addon') ?></strong>

						<input type="text" id="est_delivery_date" readonly value="<?php echo $est_delivery_date; ?>"></p>
					</li>

					<?php

				}

				?>
				<li id="" class="wide">

					<strong><?php _e($this->settings_obj->display_text, 'ph_order_delivery_date_addon') ?></strong>
					
					<input type="text" id="order_delivery_date" class="ph-date-picker" value="<?php echo $order_delivery_date; ?>" autocomplete="off"></p>
				</li>

				<li id="" class="wide">
					<button type="submit" class="button save_date button-primary" data-tip="<?php _e( 'Update', 'ph_order_delivery_date_addon' ); ?>"><?php _e('Update', 'ph_order_delivery_date_addon'); ?></button>
				</li>
			</ul>
			<script>

				jQuery(document).ready(function($) {

					let maxDate 			= <?php echo $max_day_limit; ?>;
					let non_working_date 	= <?php echo json_encode($non_working_days); ?>;
					
					$( ".ph-date-picker" ).datepicker({
						minDate: 		<?php echo $min_delivery_days?>,
						dateFormat: 	<?php echo '"'.$display_format.'"'; ?>,
						beforeShowDay: 	non_working,
					});

					if ( maxDate > 0 ) {
						$(".ph-date-picker").datepicker("option", "maxDate", maxDate);
					}	

					function non_working(date) {

						for ( i = 0; i < non_working_date.length; i++ ) {

							var day = date.getDay();
							return [ non_working_date.indexOf(day) == -1 ]
						}
					}	
				});

				jQuery("button.save_date").on("click", function(e) {

					if( jQuery.trim(jQuery('#order_delivery_date').val()) !== '' ) {

						e.preventDefault();

						var html = "<input type='hidden' name='update_order_delivery_date' value='"+jQuery('#order_delivery_date').val()+"'  >\
						";

						jQuery("form[name='post']").append(html);

						jQuery("form[name='post']").submit();
					}
				});

				jQuery("button.save_order").on("click", function(e) {

					if( jQuery.trim(jQuery('#order_delivery_date').val()) !== '') {

						e.preventDefault();

						var html = "<input type='hidden' name='update_order_delivery_date' value='"+jQuery('#order_delivery_date').val()+"'  >\
						";

						jQuery("form[name='post']").append(html);

						jQuery("form[name='post']").submit();
					}
				});

			</script>
			<?php
		}

		public function ph_update_order_delivery_date_meta_data() {

			$post_id 		= isset( $_POST['post_ID'] ) ? $_POST['post_ID'] : '';
			$date			= isset( $_POST[ 'update_order_delivery_date' ] ) ? $_POST[ 'update_order_delivery_date' ] : '';

			if ( !empty( $date ) ) {

				update_post_meta( $post_id, '_ph_order_delivery_date_value', $date );
			}
		}


	}

	new PH_Order_Delivery_Date_Admin_Helper();
}