<?php

if( !class_exists('PH_Order_Delivery_Date_Settings_Option') ){

	class PH_Order_Delivery_Date_Settings_Option {

		public function __construct() {

			$settings 					= get_option('ph_order_delivery_date_addon');
			$this->settings 			= !empty($settings)? $settings : array();

			$enable 					= get_option('enable');
			$this->settings_enable 		= ( isset($enable) && !empty($enable) && $enable == 'yes' ) ? true : false;

			$min_delivery_days 			= get_option('min_delivery_days');
			$this->min_delivery_days 	= ( isset( $min_delivery_days ) && !empty( $min_delivery_days ) ) ? $min_delivery_days  : 0;

			$max_day_limit 				= get_option('max_day_limit');
			$this->max_day_limit 		= ( isset( $max_day_limit ) && !empty( $max_day_limit ) ) ? $max_day_limit  :0;

			$display_text 				= get_option('display_text');
			$this->display_text 		= !empty( $display_text ) ? __($display_text,'ph_order_delivery_date_addon') : __('Order Delivery Date', 'ph_order_delivery_date_addon' );

			$odd_display_format 			= get_option('ph_display_format');
			$this->odd_display_format 		= !empty( $odd_display_format ) ? $odd_display_format : 'yy-mm-dd';

			// $odd_custom_format 			= get_option('ph_custom_format');
			// $this->odd_custom_format 		= !empty( $odd_custom_format ) ? $odd_custom_format : 'yy-mm-dd';

			$this->ph_estimated_delivery_is_active 	= $this->ph_check_for_estimated_delivery_plugin();

			// Estimated Delivery Date Plugin Compatibilty
			if ( $this->ph_estimated_delivery_is_active  ) {

				add_filter( 'xa_estimated_delivery_cart_checkout_page_html_formatted_date', array($this, 'ph_update_estimated_delivery_plugin_date_in_session'), 12, 4 );

				$page_text_format 		= get_option('wf_estimated_delivery_page_text_format');
				$this->page_text_format = !empty( $page_text_format ) ? $page_text_format : '';

				$this->display_format 	= get_option( 'wf_estimated_delivery_date_display_format' );

				$cart_page_text 		= get_option('wf_estimated_delivery_cart_page_text');
				$this->cart_page_text 	= !empty( $cart_page_text ) ? __($cart_page_text,'wf_estimated_delivery') : __('Estimated Delivery', 'wf_estimated_delivery' );
				$all_working_days 		= array( 'sun', 'mon', 'tue', 'wed', 'thu', 'fri', 'sat' );

				$ph_workdays 			= get_option( 'wf_estimated_delivery_operation_days' );
				$this->ph_workdays		= !empty( $ph_workdays  ) ? $ph_workdays : $all_working_days ;

				$this->non_working_days  = $this->ph_get_non_working_days( $this->ph_workdays );
			}

			$this->ph_backorder_addon_is_active  = $this->ph_check_for_backorder_addon();

			// Backorder Addon Compatibilty			
			if ( $this->ph_estimated_delivery_is_active && $this->ph_backorder_addon_is_active ) {

				add_action( 'ph_backorder_addon_order_delivery_date', array( $this, 'ph_update_backorder_delivery_date_in_session' ), 12, 1 );
			}

			add_action( 'wp_ajax_ph_get_estimated_date_for_addon', array( $this, 'ph_get_estimated_date_for_addon') );
		}

		public function ph_update_backorder_delivery_date_in_session( $backorder_date ) {

			if( !empty( $backorder_date) ) {

				$estDate        = DateTime::createFromFormat($this->display_format, $backorder_date);
				$addon_date     = $estDate->format('Y-m-d');
				$new_date       = new DateTime();
				$current_date   = $new_date ->format('Y-m-d');
				$interval       = ( strtotime($addon_date) - strtotime($current_date) ) / 24 / 3600;

				if ( WC() != null && WC()->session != null ) {

					WC()->session->set('ph_addon_date', $interval);
				}

			} else {

				if ( WC() != null && WC()->session != null ) {

					WC()->session->set('ph_addon_date', 0);
				}
			}
		}

		public function ph_update_estimated_delivery_plugin_date_in_session( $text, $test, $date, $estimated_date ) {

			if ( isset( $estimated_date ) && !empty( $estimated_date ) ) {

				// If - For Simple and Date Range
				// Else - For Simple Range
				if ( $this->page_text_format == 'simple' || $this->page_text_format == 'date_range' ) {

					$estDate        = DateTime::createFromFormat($this->display_format, $estimated_date);
					$plugin_date    = $estDate->format('Y-m-d');
					$new_date       = new DateTime();
					$current_date   = $new_date ->format('Y-m-d');
					$interval       = ( strtotime($plugin_date) - strtotime($current_date) ) / 24 / 3600;

					if ( WC() != null && WC()->session != null ) {

						WC()->session->set('ph_plugin_date', $interval);
					}

				} else {

					$interval       = $estimated_date;

					if ( WC() != null && WC()->session != null ) {

						WC()->session->set('ph_plugin_date', $interval);
					}
				}
			}

			return $text;
		}

		public function ph_check_for_estimated_delivery_plugin() {

			$estimated_delivery_plugin_is_active 	= false;

			$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) );

			if ( in_array( 'wf-estimated-delivery-for-woocommerce/wf-estimated-delivery.php', $active_plugins ) ) {

				$estimated_delivery_plugin_is_active = true;
			}

			return $estimated_delivery_plugin_is_active;
		}

		public function ph_check_for_backorder_addon() {

			$backorder_addon_is_active 	= false;

			$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) );

			if ( in_array( 'ph-estimated-delivery-backorder-addon/ph-estimated-delivery-backorder-addon.php', $active_plugins ) ) {

				$backorder_addon_is_active = true;
			}

			return $backorder_addon_is_active;
		}

		public function ph_get_non_working_days($working_days) {

			$day_order = array(
				0 => 'sun',
				1 => 'mon',
				2 => 'tue',
				3 => 'wed',
				4 => 'thu',
				5 => 'fri',
				6 => 'sat',
			);

			$non_working_days_difference 	= array_diff($day_order, $working_days);
			$non_working_days 				= array_keys($non_working_days_difference);
			
			return $non_working_days;
		}

		public function ph_get_estimated_date_for_addon() {

			$minDate 	= 0;

			if ( WC() != null && WC()->session != null ) {

				if ( ! $this->ph_estimated_delivery_is_active ) {

					WC()->session->__unset( 'ph_plugin_date' );
				}

				if ( ! $this->ph_backorder_addon_is_active ) {

					WC()->session->__unset( 'ph_addon_date' );
				}

				$minDate    = !empty( WC()->session->get('ph_addon_date')) ? WC()->session->get('ph_addon_date') : WC()->session->get('ph_plugin_date');
				
				// Pass Minimum Deivery Date to Edit Order Page to update Meta Data
				WC()->session->set( 'ph_order_delivery_min_date', $minDate);

			}

			// Disable days in datepicker based on Working Days
			// If empty pass 7 as all are working days ( 0 = Sun & 6 = Sat )
			$non_working_days = !empty( $this->non_working_days ) ? $this->non_working_days : array( 0 => 7 );

			// min_days: Estimated Delivery Date/Backorder Date + Order Delivery Date Minimum Days
			// max_days: Order Delivery Date Maximum Days
			// extra_days: Order Delivery Date Minimum Days
			// non_working_days: Non Working Days from Estimated Delivery Date Plugin

			$display_format 	= $this->odd_display_format;

			// if( $this->odd_display_format == 'custom' ) {

			// 	$display_format 	= $this->odd_custom_format;
			// }

			$settings   = array(
				'min_days' 			=> $this->min_delivery_days + $minDate,									
				'max_days' 			=> $this->max_day_limit,
				'extra_days' 		=> $minDate,
				'date_format'		=> $display_format,
				'non_working_days' 	=> $non_working_days,
			);

			echo print_r( json_encode($settings),true);
			
			exit;
		}

	}

	new PH_Order_Delivery_Date_Settings_Option();
}