<?php

	/*
	* Plugin Name: WooCommerce Order Delivery Date Plugin
	* Plugin URI://www.pluginhive.com/plugins/
	* Description: This addon allows customers to select the delivery date.
	* Author: PluginHive
	* Author URI: https://pluginhive.com/
	* Version: 1.0.0
	* Text Domain: ph_order_delivery_date_addon
	* Copyright: 2021 PluginHive.
	* WC requires at least: 3.0.0
	* WC tested up to: 5.5.2
	*/

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	function ph_check_for_order_delivery_date_required_plugin() {

		$ph_addon_required_plugin 	= false;

		$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins', array() ) );

		// Multisite case
		if ( is_multisite() ) {
			$active_plugins = array_merge( $active_plugins, array_keys( get_site_option( 'active_sitewide_plugins', array() ) ) );
		}

		if ( in_array( 'woocommerce/woocommerce.php', $active_plugins ) ) {

			$ph_addon_required_plugin = true;
		}

		return $ph_addon_required_plugin;
	}

	// Auto Deactivate
	add_action( 'admin_init', 'ph_order_delivery_date_addon_deactivate' );

	if ( ! function_exists( 'ph_order_delivery_date_addon_deactivate' ) ) {

		function ph_order_delivery_date_addon_deactivate() {

			$ph_required_plugin	= ph_check_for_order_delivery_date_required_plugin();

			if ( !$ph_required_plugin ) {

				deactivate_plugins( plugin_basename( __FILE__ ) );
				wp_safe_redirect( admin_url('plugins.php') );
			}
		}
	}

	function ph_order_delivery_date_addon_activation_check() {

		$ph_required_plugin 	= ph_check_for_order_delivery_date_required_plugin();

		if(  !$ph_required_plugin ) {

			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing this without activating woocommerce.", 'ph_order_delivery_date_addon' ), "", array('back_link' => 1 ));
		}

	}

	register_activation_hook( __FILE__, 'ph_order_delivery_date_addon_activation_check' );

	if( !class_exists('PH_Order_Delivery_Date_Addon') ) {

		class PH_Order_Delivery_Date_Addon {

			public function __construct() {

				$this->id		= 'ph_order_delivery_date_addon';

				add_filter( 'woocommerce_settings_tabs_array', array( $this, 'ph_order_delivery_date_addon_settings_tab'), 50 );
				add_action( 'woocommerce_settings_tabs_'.$this->id, array( $this, 'ph_order_delivery_date_addon_output') );
				add_action( 'woocommerce_update_options_'.$this->id, array( $this, 'ph_order_delivery_date_addon_update') );
				add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'ph_order_delivery_date_addon_action_links' ) );
				add_action( 'admin_enqueue_scripts', array( $this, 'ph_order_delivery_admin_scripts' ) );

				include_once( 'includes/ph_order_delivery_date_settings_option.php' );

				$settings_obj = new PH_Order_Delivery_Date_Settings_Option();

				require_once( 'includes/ph_order_delivery_date_admin_helper.php' );
			}

			public function ph_get_settings_url() {

				return version_compare(WC()->version, '1.0', '>=') ? "wc-settings" : "woocommerce_settings";
			}

			public function ph_order_delivery_date_addon_action_links( $links ) {

				$plugin_links = array(

					'<a href="' . admin_url( 'admin.php?page=' . $this->ph_get_settings_url() . '&tab=ph_order_delivery_date_addon' ) . '">' . __( 'Settings', 'ph_order_delivery_date_addon' ) . '</a>',
				);

				return array_merge( $plugin_links, $links );
			}

			public function ph_order_delivery_date_addon_settings_tab( $settings_tabs ) {

				$settings_tabs[$this->id] = __( 'Order Delivery Date', 'Ph_Order_Estimated_Delivery_Date_Addon' );

				return $settings_tabs;
			}

			public function ph_order_delivery_date_addon_output() {

				woocommerce_admin_fields( $this->ph_order_delivery_date_addon_get_settings() );
			}

			public function ph_order_delivery_date_addon_update() {

				woocommerce_update_options( $this->ph_order_delivery_date_addon_get_settings() );
			}

			
			public function ph_order_delivery_date_addon_get_settings() {

				$settings = array(
					'backorder_title' => array(
						'title' 		=> __( 'Wocoomerce Order Delivery Date ', 'ph_order_delivery_date_addon' ),
						'type' 			=> 'title',
						'id' 			=> 'addon_title',
						'value' 		=> __( 'Wocoomerce Order Delivery Date', 'ph_order_delivery_date_addon' ),
					),
					'enable' => array(
						'title' 		=> __('Enable', 'ph_order_delivery_date_addon'),
						'type' 			=> 'checkbox',
						'default' 		=> 'no',
						'desc'			=> __(' Enable<br/><small> This addon allows customers to select the delivery date.</small>', 'ph_order_delivery_date_addon' ),
						'id'			=> 'enable'
					),
					'display_text'	=>	array(
						'type'			=> 'text',
						'id'			=> 'display_text',
						'desc'			=> __( 'Enter text which gets displayed on  Checkout, Admin Order, Order Received Page and Email beside which the Order delivery date is shown.','ph_order_delivery_date_addon'),
						'placeholder'	=> __( 'Order Delivery Date', 'ph_order_delivery_date_addon'),
						'default'		=> __( 'Order Delivery Date', 'ph_order_delivery_date_addon'),
						'name'			=> __( 'Display Text', 'ph_order_delivery_date_addon' ),
						'desc_tip'		=> true,
					),
					'min_delivery_days' => array(
						'title' 		=> __( 'Minimum Delivery Days for Selection', 'ph_order_delivery_date_addon' ),
						'type'			=> 'number',
						'desc'			=> __( "The customers will have to select desired delivery date after the number of days specified in this option.",'ph_order_delivery_date_addon'),
						'desc_tip'		=> true,
						'default'  		=> 0,
						'placeholder' 	=> 0,
						'id'			=> 'min_delivery_days'
					),
					'max_day_limit' => array(
						'title'			=> __( 'Maximum Delivery Days for Selection', 'ph_order_delivery_date_addon' ),
						'type'			=> 'number',
						'desc'			=> __("The customers can select desired delivery date up to a maximum of the number of days specified in this option.",'ph_order_delivery_date_addon'),
						'desc_tip'		=> true,
						'default'  		=> '',
						'placeholder' 	=> 'Unlimited',
						'id'			=> 'max_day_limit'
					),
					'ph_display_format'	=>	array(
						'type'			=> 'select',
						'id'			=> 'ph_display_format',
						'desc'			=> __( '<small><b>Enter the display format which gets displayed on  Checkout, Admin Order, Order Received Page and Email. </b></small><br/><small> d - day of month (no leading zero) <b>|</b> dd - day of month (two digit)<br/>m - month of year (no leading zero) <b>|</b> mm - month of year (two digit)<br/>y - year (two digit) <b>|</b> yy - year (four digit) <b>|</b> M - month name short </small>','ph_order_delivery_date_addon'),
						'default'		=> 'yy-mm-dd',
						'name'			=> __( 'Date Display Format', 'ph_order_delivery_date_addon' ),
						'options'		=> array(

							'yy-mm-dd'	=> 'yy-mm-dd',
							'mm-dd-yy'	=> 'mm-dd-yy',
							'dd-mm-yy'	=> 'dd-mm-yy',

							'M dd, y'	=> 'M dd, y',
							'dd M, y'	=> 'dd M, y',
							'M dd, yy'	=> 'M dd, yy',
							'dd M, yy'	=> 'dd M, yy',

							'y/m/d'		=> 'y/m/d',
							'm/d/y'		=> 'm/d/y',
							'd/m/y'		=> 'd/m/y',

							// 'custom'	=> 	__( '-- Custom --', 'ph_order_delivery_date_addon' ),
						),
					),
					// 'ph_custom_format'	=>	array(
					// 	'type'			=> 'text',
					// 	'id'			=> 'ph_custom_format',
					// 	'desc'			=> __( '<b>Supported Formats:</b><br/>d - day of month (no leading zero) | dd - day of month (two digit)<br/>D - day name short | DD - day name long<br/>m - month of year (no leading zero) | mm - month of year (two digit)<br/>M - month name short | MM - month name long<br/>y - year (two digit) | yy - year (four digit)','ph_order_delivery_date_addon'),
					// 	'default'		=> '',
					// 	'name'			=> __( 'Custom Format', 'ph_order_delivery_date_addon' ),
					// ),
					'section_end' => array(
						'type'			=> 'sectionend',
						'id'			=> 'ph_order_delivery_date_addon',
						'value'			=> '',
					)

				);

				return apply_filters( 'wc_settings_ph_order_delivery_date_addon_settings', $settings );
			}

			public function ph_order_delivery_admin_scripts() {
				
				wp_enqueue_script( 'ph-order-delivery-script', plugins_url( '/resources/js/ph-admin.js', __FILE__ ), array( 'jquery' ) );
			}
		}

		new PH_Order_Delivery_Date_Addon();
	}

	// Plugin Updater
	require 'plugin-update-checker/plugin-update-checker.php';

	$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
		'https://bitbucket.org/pluginhive/ph-order-delivery-date-for-woocommerce/',
		__FILE__,
		'ph-order-delivery-date-for-woocommerce'
	);

	$myUpdateChecker->setAuthentication(array(
		'consumer_key' => 'nXGsrkFGPS86v9eHnK',
		'consumer_secret' => 'G5SHXQtbg8Yp9dpkuMhSmvLYQWkhG97x',
	));